# Support

Thank you for using ETLPlus!

## Where to Get Help

- **Questions & Usage**: Please use [GitHub Discussions][discussions] for general questions, usage
  help, and best practices.
- **Bugs & Feature Requests**: Open an issue in the [GitHub Issues][issues] tracker.
- **Security Issues**: See [SECURITY.md](SECURITY.md) for responsible disclosure.
- **Documentation**: See the [README](README.md) and [docs/](docs/) directory for guides and
  references.

We aim to respond to questions and issues as quickly as possible. Community contributions and peer
support are also welcome!

[discussions]: https://github.com/Dagitali/ETLPlus/discussions
[issues]: https://github.com/Dagitali/ETLPlus/issues
